# MoinMoin To Git Wiki Conversion Tools

The tools are a set of command line tools under the name `moin2gitwiki`.

::: mkdocs-click
    :module: moin2gitwiki.cli
    :command: moin2gitwiki
    :depth: 1
